@@ -86,6 +86,7 @@ import javax.swing.table.TableColumnModel;
 import org.astrogrid.samp.client.DefaultClientProfile;
 import uk.ac.starlink.plastic.PlasticUtils;
 import uk.ac.starlink.table.DescribedValue;
+import uk.ac.starlink.table.RowRunner;
 import uk.ac.starlink.table.StarTable;
 import uk.ac.starlink.table.StarTableFactory;
 import uk.ac.starlink.table.StarTableOutput;
@@ -190,6 +191,7 @@ public class ControlWindow extends AuxWindow
     private final Window window_ = this;
     private final ButtonModel dummyButtonModel_ = new DefaultButtonModel();
     private StarTableFactory tabfact_ = new StarTableFactory( true );
+    private final RowRunner runner_ = RowRunner.DEFAULT;
     private final boolean showListToolBar_ = false;
     private LoadWindow loadWindow_;
     private SaveQueryWindow saveWindow_;
@@ -778,6 +780,15 @@ public class ControlWindow extends AuxWindow
         return communicator_;
     }
 
+    /**
+     * Returns the RowRunner to be used for multithreaded table processing.
+     *
+     * @return  row runner
+     */
+    public RowRunner getRowRunner() {
+        return runner_;
+    }
+
     /**
      * Adds a table to this windows list.
      * Following this, a user will be able to do TOPCATty things with
@@ -1958,15 +1969,20 @@ public class ControlWindow extends AuxWindow
      * @return  possibly shortened version
      */
     private static String shorten( String label ) {
-        int sindex = label.lastIndexOf( '/' );
-        if ( sindex < 0 || sindex == label.length() - 1 ) {
-            sindex = label.lastIndexOf( '\\' );
+        if ( label.matches( ":([a-zA-Z0-9_-]+):(.*)" ) ) {
+            // scheme syntax - leave it alone
         }
-        if ( sindex < 0 || sindex == label.length() - 1 ) {
-            sindex = label.lastIndexOf( ':' );
-        }
-        if ( sindex > 0 && sindex < label.length() - 1 ) {
-            label = label.substring( sindex + 1 );
+        else {
+            int sindex = label.lastIndexOf( '/' );
+            if ( sindex < 0 || sindex == label.length() - 1 ) {
+                sindex = label.lastIndexOf( '\\' );
+            }
+            if ( sindex < 0 || sindex == label.length() - 1 ) {
+                sindex = label.lastIndexOf( ':' );
+            }
+            if ( sindex > 0 && sindex < label.length() - 1 ) {
+                label = label.substring( sindex + 1 );
+            }
         }
         if ( label.length() > 48 ) {
             label = label.substring( 0, 48 ) + "...";
