@@ -45,7 +45,7 @@ public class ParameterWindow extends AuxWindow
     private TableModel viewModel;
     private TableColumnModel columnModel;
     private ParamList params;
-    private Collection uneditableParams;
+    private Collection<DescribedValue> uneditableParams;
     private DescribedValue ncolParam;
     private DescribedValue nrowParam;
     private final MetaColumnTableModel metaTableModel;
@@ -101,7 +101,7 @@ public class ParameterWindow extends AuxWindow
 
         /* Also maintain a record of subsets of this list which have
          * certain characteristics. */
-        uneditableParams = new HashSet();
+        uneditableParams = new HashSet<DescribedValue>();
 
         /* Make a parameter for the table name. */
         DescribedValue nameParam = new DescribedValue( NAME_INFO ) {
@@ -151,7 +151,7 @@ public class ParameterWindow extends AuxWindow
         /* Assemble a list of MetaColumns which hold information about
          * the columns in the JTable this component will display.
          * Each column holds one item of information about a DescribedValue. */
-        List metas = new ArrayList();
+        List<MetaColumn> metas = new ArrayList<MetaColumn>();
 
         /* Add name column. */
         metas.add( new MetaColumn( NAME_NAME, String.class ) {
@@ -175,7 +175,8 @@ public class ParameterWindow extends AuxWindow
             }
             public boolean isEditable( int irow ) {
                 if ( isEditableParameter( irow ) ) {
-                    Class clazz = getParam( irow ).getInfo().getContentClass();
+                    Class<?> clazz =
+                        getParam( irow ).getInfo().getContentClass();
 
                     /* Not all value types can be edited, since the 
                      * ValueInfo.unformatString() method doesn't work in all
@@ -414,7 +415,7 @@ public class ParameterWindow extends AuxWindow
                                      "Delete the selected parameter" ) {
             public void actionPerformed( ActionEvent evt ) {
                 TopcatModel tcm = ParameterWindow.this.tcModel;
-                List removals = new ArrayList();
+                List<DescribedValue> removals = new ArrayList<DescribedValue>();
                 for ( int irow = rowSelectionModel.getMinSelectionIndex();
                       irow <= rowSelectionModel.getMaxSelectionIndex();
                       irow++ ) {
@@ -434,8 +435,8 @@ public class ParameterWindow extends AuxWindow
                 if ( ! removals.isEmpty() ) {
                     rowSelectionModel.clearSelection();
                 }
-                for ( Iterator it = removals.iterator(); it.hasNext(); ) {
-                    tcm.removeParameter( (DescribedValue) it.next() );
+                for ( DescribedValue dval : removals ) {
+                    tcm.removeParameter( dval );
                 }
             }
         };
@@ -460,7 +461,7 @@ public class ParameterWindow extends AuxWindow
     }
 
     private DescribedValue getParam( int irow ) {
-        return (DescribedValue) params.get( irow );
+        return params.get( irow );
     }
 
     private ValueInfo getParamInfo( int irow ) {
@@ -543,7 +544,6 @@ public class ParameterWindow extends AuxWindow
             }
             removeAct.setEnabled( active );
             detailPanel.setItem( index,
-                                 (DescribedValue)
                                  ( index >= 0
                                    ? params.get( toUnsortedIndex( index ) )
                                    : null ) );
@@ -554,13 +554,13 @@ public class ParameterWindow extends AuxWindow
      * Helper class that holds two lists together - one list of 'pseudo'
      * parameters and one list of 'normal' ones.
      */
-    private static class ParamList extends AbstractList {
-        private final List pseudoParams;
-        private final List normalParams;
+    private static class ParamList extends AbstractList<DescribedValue> {
+        private final List<DescribedValue> pseudoParams;
+        private final List<DescribedValue> normalParams;
 
-        ParamList( List normalParams ) {
+        ParamList( List<DescribedValue> normalParams ) {
             this.normalParams = normalParams;
-            this.pseudoParams = new ArrayList();
+            this.pseudoParams = new ArrayList<DescribedValue>();
         }
 
         public void addPseudoParameter( DescribedValue dval ) {
@@ -571,7 +571,7 @@ public class ParameterWindow extends AuxWindow
             return pseudoParams.size() + normalParams.size();
         }
 
-        public Object get( int index ) {
+        public DescribedValue get( int index ) {
             if ( isPseudoParam( index ) ) {
                 return pseudoParams.get( index );
             }
