@@ -1,18 +1,12 @@
 package uk.ac.starlink.topcat;
 
 import gnu.jel.CompilationException;
-import gnu.jel.CompiledExpression;
-import gnu.jel.Evaluator;
-import gnu.jel.Library;
-import gnu.jel.Parser;
 import java.io.IOException;
-import java.util.Hashtable;
 import java.util.logging.Logger;
 import uk.ac.starlink.table.ColumnData;
 import uk.ac.starlink.table.ColumnInfo;
 import uk.ac.starlink.table.DescribedValue;
 import uk.ac.starlink.table.ValueInfo;
-import uk.ac.starlink.ttools.jel.RandomJELRowReader;
 
 /**
  * A column which produces read-only values based on an algebraic
@@ -30,16 +24,16 @@ import uk.ac.starlink.ttools.jel.RandomJELRowReader;
  */
 public class SyntheticColumn extends ColumnData {
 
-    private CompiledExpression compEx_;
-    private RandomJELRowReader rowReader_;
+    private final TopcatModel tcModel_;
+    private TopcatJELEvaluator evaluator_;
 
     private static Logger logger = Logger.getLogger( "uk.ac.starlink.topcat" );
 
-
     /**
      * Constructs a new synthetic column from an algebraic expression 
      * applied to a table.
      *
+     * @param  tcModel  context for JEL expression evaluation
      * @param  cinfo   metadata for the new column;
      *                 note this object may be modified as required by
      *                 the supplied expression
@@ -48,13 +42,13 @@ public class SyntheticColumn extends ColumnData {
      * @param  resultType  a Class for the result, presumably one of the
      *         primitive wrapper types or String.class.  If <tt>null</tt>
      *         a suitable class is chosen automatically.
-     * @param  rowReader  context for JEL expression evaluation
      */
-    public SyntheticColumn( ColumnInfo cinfo, String expression,
-                            Class<?> resultType, RandomJELRowReader rowReader )
+    public SyntheticColumn( TopcatModel tcModel, ColumnInfo cinfo,
+                            String expression, Class<?> resultType )
             throws CompilationException {
         super( cinfo );
-        setExpression( expression, resultType, rowReader );
+        tcModel_ = tcModel;
+        setExpression( expression, resultType );
     }
 
     /**
@@ -68,23 +62,14 @@ public class SyntheticColumn extends ColumnData {
      * @param  resultType  a Class for the result, presumably one of the
      *         primitive wrapper types or String.class.  If <tt>null</tt>
      *         a suitable class is chosen automatically.
-     * @param  rowReader  context for JEL expression evaluation
      */
-    public void setExpression( String expression, Class<?> resultType,
-                               RandomJELRowReader rowReader ) 
+    public void setExpression( String expression, Class<?> resultType )
             throws CompilationException {
 
         /* Compile the expression. */
-        Library lib = TopcatJELUtils.getLibrary( rowReader, false );
-        compEx_ = Evaluator.compile( expression, lib, resultType );
-        rowReader_ = rowReader;
-
-        /* Work out the type of the compiled expression. */
-        Class<?> actualType =
-            new Parser( expression, lib ).parse( resultType ).resType;
-        if ( actualType.isPrimitive() ) {
-            actualType = TopcatJELUtils.wrapPrimitiveClass( actualType );
-        }
+        evaluator_ = TopcatJELEvaluator
+                    .createEvaluator( tcModel_, expression, false, resultType );
+        Class<?> actualType = evaluator_.getResultType();
 
         /* Configure the column data type correctly for this expression. */
         ColumnInfo colinfo = getColumnInfo();
@@ -101,13 +86,12 @@ public class SyntheticColumn extends ColumnData {
      * @return  expression
      */
     public String getExpression() {
-        return getColumnInfo().getAuxDatum( TopcatUtils.EXPR_INFO )
-              .getValue().toString();
+        return evaluator_.getExpression();
     }
 
     public Object readValue( long lrow ) throws IOException {
         try {
-            return rowReader_.evaluateAtRow( compEx_, lrow );
+            return evaluator_.evaluateObject( lrow );
         }
         catch ( RuntimeException e ) {
             logger.info( e.toString() );
@@ -118,5 +102,4 @@ public class SyntheticColumn extends ColumnData {
                                .initCause( th );
         }
     }
-
 }
