@@ -40,6 +40,7 @@ import uk.ac.starlink.table.ColumnInfo;
 import uk.ac.starlink.table.ColumnPermutedStarTable;
 import uk.ac.starlink.table.DescribedValue;
 import uk.ac.starlink.table.RowListStarTable;
+import uk.ac.starlink.table.RowSequence;
 import uk.ac.starlink.table.ShapeIterator;
 import uk.ac.starlink.table.StarTable;
 import uk.ac.starlink.table.StarTableOutput;
@@ -48,7 +49,6 @@ import uk.ac.starlink.table.ValueInfo;
 import uk.ac.starlink.table.gui.StarTableColumn;
 import uk.ac.starlink.topcat.activate.ActivationMeta;
 import uk.ac.starlink.topcat.activate.ActivationWindow;
-import uk.ac.starlink.ttools.jel.RandomJELRowReader;
 import uk.ac.starlink.ttools.convert.Conversions;
 import uk.ac.starlink.ttools.convert.ValueConverter;
 
@@ -669,7 +669,6 @@ public class TopcatModel {
         String baseExpr = baseInfo.getAuxDatum( TopcatUtils.COLID_INFO )
                                   .getValue().toString();
         ColumnInfo elInfo = new ColumnInfo( baseInfo );
-        RandomJELRowReader rowReader = createJELRowReader();
         elInfo.setShape( null );
         int ipos = 0;
         for ( Iterator<int[]> it = new ShapeIterator( baseInfo.getShape() );
@@ -687,7 +686,7 @@ public class TopcatModel {
             String colExpr = baseExpr + '[' + ipos + ']';
             try {
                 SyntheticColumn elcol =
-                    new SyntheticColumn( colInfo, colExpr, null, rowReader );
+                    new SyntheticColumn( this, colInfo, colExpr, null );
                 appendColumn( elcol, ++insertPos );
             }
             catch ( CompilationException e ) {
@@ -775,10 +774,16 @@ public class TopcatModel {
      * so it should only be used for preparation of evaluation of expressions
      * at call time, not saved for use in compiling expressions acquired later.
      *
+     * <p>Note this currently returns a one-size-fits-all implementation,
+     * safe for multi-thread use.  But it may not be efficient for
+     * multi-thread use (synchronization, contention).
+     * This should be fixed so that efficient single-threaded access
+     * is possible.
+     *
      * @return  row reader
      */
-    public RandomJELRowReader createJELRowReader() {
-        return new TopcatJELRowReader( this );
+    public TopcatJELRowReader createJELRowReader() {
+        return TopcatJELRowReader.createConcurrentReader( this );
     }
 
     /**
@@ -820,14 +825,13 @@ public class TopcatModel {
      * Where this can't be done, a warning is issued.
      */
     public void recompileSubsets() {
-        RandomJELRowReader jeller = createJELRowReader();
         int nset = subsets_.size();
         for ( int is = 0; is < nset; is++ ) {
             RowSubset rs = subsets_.get( is );
             if ( rs instanceof SyntheticRowSubset ) {
                 SyntheticRowSubset ss = (SyntheticRowSubset) rs;
                 try {
-                    ss.setExpression( ss.getExpression(), jeller );
+                    ss.setExpression( ss.getExpression() );
                 }
                 catch ( CompilationException e ) {
                     logger_.warning( "Can't recompile expression "
@@ -916,9 +920,13 @@ public class TopcatModel {
         final int sense = ascending ? 1 : -1;
          
         /* Define a little class for objects being sorted. */
-        class Item implements Comparable<Item> { 
-            int rank;
-            Comparable<?> value;
+        class Item implements Comparable<Item> {
+            final int rank;
+            final Comparable<?> value;
+            Item( int r, Comparable<?> v ) {
+                this.rank = r;
+                this.value = v;
+            }
             public int compareTo( Item other ) {
                 Comparable<?> oval = other.value;
                 if ( value != null && oval != null ) {
@@ -938,17 +946,18 @@ public class TopcatModel {
         /* Construct a list of all the elements in the given column. */
         int nrow = AbstractStarTable
                   .checkedLongToInt( dataModel_.getRowCount() );
-        ColumnData coldata = dataModel_.getColumnData( icol );
         Item[] items = new Item[ nrow ];
-        for ( int i = 0; i < nrow; i++ ) {
-            Item item = new Item();
-            item.rank = i;
-            item.value = (Comparable<?>) coldata.readValue( (long) i );
-            items[ i ] = item;
+        try ( RowSequence rseq = dataModel_.getRowSequence() ) {
+            int ir = 0;
+            while ( rseq.next() ) {
+                items[ ir ] =
+                    new Item( ir, (Comparable<?>) rseq.getCell( icol ) );
+                ir++;
+            }
         }
 
         /* Sort the list on the ordering of the items. */
-        Arrays.sort( items );
+        Arrays.parallelSort( items );
 
         /* Construct and return a list of reordered ranks from the
          * sorted array. */
