@@ -10,7 +10,9 @@ import uk.ac.starlink.table.StarTable;
 import uk.ac.starlink.table.StarTableFactory;
 import uk.ac.starlink.table.TableBuilder;
 import uk.ac.starlink.table.TablePreparation;
+import uk.ac.starlink.table.TableScheme;
 import uk.ac.starlink.table.ValueInfo;
+import uk.ac.starlink.ttools.Stilts;
 
 /**
  * TablePreparation implementation that can store and retrieve information
@@ -96,6 +98,9 @@ public class TopcatPreparation implements TablePreparation {
      */
     public static StarTableFactory createFactory() {
         StarTableFactory tfact = new StarTableFactory( true );
+        for ( TableScheme scheme : Stilts.getStandardSchemes() ) {
+            tfact.addScheme( scheme );
+        }
         tfact.setPreparation( new TopcatPreparation( tfact.getPreparation() ) );
         return tfact;
     }
