@@ -15,6 +15,7 @@ import javax.swing.table.TableColumnModel;
 import uk.ac.starlink.table.ColumnData;
 import uk.ac.starlink.table.ColumnInfo;
 import uk.ac.starlink.table.gui.StarTableColumn;
+import uk.ac.starlink.topcat.ColumnDataComboBox;
 import uk.ac.starlink.topcat.ColumnDataComboBoxModel;
 import uk.ac.starlink.topcat.Outcome;
 import uk.ac.starlink.topcat.TopcatModel;
@@ -28,12 +29,11 @@ import uk.ac.starlink.util.URLUtils;
  * @author   Mark Taylor
  * @since    21 Dec 2017
  */
-@SuppressWarnings({"unchecked","rawtypes"})
 public abstract class UrlColumnConfigurator
                 extends AbstractActivatorConfigurator {
 
     private final TopcatModel tcModel_;
-    private final JComboBox colSelector_;
+    private final JComboBox<ColumnData> colSelector_;
     private final Box queryPanel_;
     private final JLabel colLabel_;
     private static final String URLCOL_KEY = "url";
@@ -58,7 +58,7 @@ public abstract class UrlColumnConfigurator
         ColumnDataComboBoxModel colModel =
             new ColumnDataComboBoxModel( tcModel_, String.class, true );
         configureDefaultSelection( colModel, tinfo, urlFlags );
-        colSelector_ = ColumnDataComboBoxModel.createComboBox();
+        colSelector_ = new ColumnDataComboBox();
         colSelector_.setModel( colModel );
         colSelector_.addActionListener( getActionForwarder() );
         colLabel_ = new JLabel( urlWord + " Location: " );
