@@ -17,6 +17,5 @@ public interface Activity {
      *
      * @return   target application selection model
      */
-    @SuppressWarnings("rawtypes")
-    ComboBoxModel getTargetSelector();
+    ComboBoxModel<?> getTargetSelector();
 }
