@@ -5,7 +5,6 @@ import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.io.IOException;
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.List;
 import java.util.regex.Pattern;
 import javax.swing.BorderFactory;
@@ -39,6 +38,7 @@ import uk.ac.starlink.util.gui.ShrinkWrapper;
  * @author   Mark Taylor
  * @since    31 May 2007
  */
+@SuppressWarnings({"unchecked","rawtypes"})
 public class SphericalAxesSelector implements AxesSelector {
 
     private final JComponent colBox_;
@@ -203,7 +203,7 @@ public class SphericalAxesSelector implements AxesSelector {
     }
 
     public StarTable getErrorData() {
-        List colList = new ArrayList();
+        List<ColumnData> colList = new ArrayList<ColumnData>();
         boolean hasTanerr = tangentErrorToggler_.isSelected();
         ErrorMode radialMode = radialVisible_
                              ? radialErrorModeModel_.getErrorMode()
@@ -222,8 +222,7 @@ public class SphericalAxesSelector implements AxesSelector {
                 colList.add( rData );
             }
         }
-        ColumnData[] eCols =
-            (ColumnData[]) colList.toArray( new ColumnData[ 0 ] );
+        ColumnData[] eCols = colList.toArray( new ColumnData[ 0 ] );
         return new ColumnDataTable( tcModel_, eCols );
     }
 
@@ -465,9 +464,7 @@ public class SphericalAxesSelector implements AxesSelector {
     private static ColumnData guessTanerrParam( TopcatModel tcModel ) {
         ColumnData bestCol = null;
         int bestScore = 0;
-        List paramList = tcModel.getDataModel().getParameters();
-        for ( Iterator it = paramList.iterator(); it.hasNext(); ) {
-            DescribedValue dval = (DescribedValue) it.next();
+        for ( DescribedValue dval : tcModel.getDataModel().getParameters() ) {
             ValueInfo info = dval.getInfo();
             Object value = dval.getValue();
             if ( value instanceof Number ) {
