@@ -2,8 +2,8 @@ package uk.ac.starlink.topcat.plot2;
 
 import java.awt.Component;
 import java.awt.Rectangle;
+import javax.swing.ListModel;
 import uk.ac.starlink.topcat.TopcatModel;
-import uk.ac.starlink.topcat.TypedListModel;
 import uk.ac.starlink.ttools.plot2.GangerFactory;
 import uk.ac.starlink.ttools.plot2.SingleGanger;
 import uk.ac.starlink.ttools.plot2.Surface;
@@ -38,7 +38,7 @@ public class CubePlotWindow
      * @param  tablesModel  list of available tables
      */
     public CubePlotWindow( Component parent,
-                           TypedListModel<TopcatModel> tablesModel ) {
+                           ListModel<TopcatModel> tablesModel ) {
         super( "Cube Plot", parent, PLOT_TYPE, PLOT_GUI, tablesModel );
         getToolBar().addSeparator();
         addHelp( "CubePlotWindow" );
@@ -58,6 +58,9 @@ public class CubePlotWindow
                   .createPanel( PLOT_TYPE.getPointDataGeoms()[ 0 ], npos,
                                 XYZ_SPOTTERS );
         }
+        public PositionCoordPanel createAreaCoordPanel() {
+            throw new UnsupportedOperationException();
+        }
         public boolean hasPositions() {
             return true;
         }
