@@ -4,6 +4,7 @@ import gnu.jel.CompilationException;
 import java.awt.event.ActionEvent;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.HashMap;
 import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
@@ -11,6 +12,7 @@ import java.util.logging.Level;
 import java.util.logging.Logger;
 import javax.swing.Action;
 import javax.swing.Icon;
+import javax.swing.ListModel;
 import uk.ac.starlink.table.ColumnData;
 import uk.ac.starlink.table.HealpixTableInfo;
 import uk.ac.starlink.topcat.BasicAction;
@@ -19,7 +21,6 @@ import uk.ac.starlink.topcat.ResourceIcon;
 import uk.ac.starlink.topcat.RowSubset;
 import uk.ac.starlink.topcat.TopcatListener;
 import uk.ac.starlink.topcat.TopcatModel;
-import uk.ac.starlink.topcat.TypedListModel;
 import uk.ac.starlink.ttools.plot.Styles;
 import uk.ac.starlink.ttools.plot2.PlotType;
 import uk.ac.starlink.ttools.plot2.PlotUtil;
@@ -29,11 +30,13 @@ import uk.ac.starlink.ttools.plot2.config.ConfigKey;
 import uk.ac.starlink.ttools.plot2.config.ConfigMap;
 import uk.ac.starlink.ttools.plot2.config.Specifier;
 import uk.ac.starlink.ttools.plot2.config.StyleKeys;
+import uk.ac.starlink.ttools.plot2.data.AreaCoord;
 import uk.ac.starlink.ttools.plot2.data.Coord;
 import uk.ac.starlink.ttools.plot2.data.CoordGroup;
 import uk.ac.starlink.ttools.plot2.data.FloatingCoord;
 import uk.ac.starlink.ttools.plot2.data.Input;
 import uk.ac.starlink.ttools.plot2.layer.HealpixPlotter;
+import uk.ac.starlink.ttools.plot2.task.CoordSpec;
 import uk.ac.starlink.util.Loader;
 
 /**
@@ -50,7 +53,7 @@ public class GroupControlManager<P,A> implements ControlManager {
     private final ControlStack stack_;
     private final PlotType<P,A> plotType_;
     private final PlotTypeGui<P,A> plotTypeGui_;
-    private final TypedListModel<TopcatModel> tablesModel_;
+    private final ListModel<TopcatModel> tablesModel_;
     private final ZoneFactory zfact_;
     private final MultiConfigger baseConfigger_;
     private final TopcatListener tcListener_;
@@ -86,7 +89,7 @@ public class GroupControlManager<P,A> implements ControlManager {
      */
     public GroupControlManager( ControlStack stack, PlotType<P,A> plotType,
                                 PlotTypeGui<P,A> plotTypeGui,
-                                TypedListModel<TopcatModel> tablesModel,
+                                ListModel<TopcatModel> tablesModel,
                                 ZoneFactory zfact, MultiConfigger baseConfigger,
                                 TopcatListener tcListener ) {
         stack_ = stack;
@@ -259,10 +262,13 @@ public class GroupControlManager<P,A> implements ControlManager {
         /* Must have the same positional coordinates.
          * This test currently requires all the coordinates to be the same,
          * I think that could be relaxed to just the positional ones. */
-        if ( ! lcmd.getInputValues()
-                   .equals( GuiCoordContent
-                           .getInputValues( control.getPositionCoordPanel()
-                                                   .getContents() ) ) ) {
+        Map<String,String> ivals = new HashMap<>();
+        GuiCoordContent[] contents =
+            control.getPositionCoordPanel().getContents();
+        for ( CoordSpec cspec : GuiCoordContent.getCoordSpecs( contents ) ) {
+            ivals.put( cspec.getInputName(), cspec.getValueExpr() );
+        }
+        if ( ! lcmd.getInputValues().equals( ivals ) ) {
             return false;
         }
 
@@ -308,7 +314,6 @@ public class GroupControlManager<P,A> implements ControlManager {
             throws LayerException {
 
         /* Create the control. */
-        int npos = lcmd.getPlotter().getCoordGroup().getPositionCount();
         CoordsType ctyp = CoordsType.getInstance( lcmd.getPlotter() );
         MultiFormLayerControl control = createGroupControl( ctyp, false );
 
@@ -409,6 +414,15 @@ public class GroupControlManager<P,A> implements ControlManager {
             }
         },
 
+        /** Plotter with shape information but no positional coordinate. */
+        AREA( ResourceIcon.PLOT_AREA, "Area", "area", true ) {
+            public <P,A> PositionCoordPanel
+                    createPositionCoordPanel( PlotType<P,A> plotType,
+                                              PlotTypeGui<P,A> plotTypeGui ) {
+                return plotTypeGui.createAreaCoordPanel();
+            }
+        },
+
         /** Plotter with four positional coordinates. */
         QUAD_POS( ResourceIcon.PLOT_QUAD, "Quad", "quadrilateral", true ) {
             public <P,A> PositionCoordPanel
@@ -518,6 +532,7 @@ public class GroupControlManager<P,A> implements ControlManager {
         public static CoordsType getInstance( Plotter<?> plotter ) {
             CoordGroup cgrp = plotter.getCoordGroup();
             int npos = cgrp.getPositionCount();
+            Coord[] extraCoords = cgrp.getExtraCoords();
 
             /* Treat HealpixPlotter as a special case since although it has
              * positional coordinates, they are not the standard coordinates
@@ -534,6 +549,11 @@ public class GroupControlManager<P,A> implements ControlManager {
 
             /* For other layer types, examine their declared characteristics
              * to decide how they are categorised. */
+            else if ( npos == 0 &&
+                      extraCoords.length > 0 &&
+                      extraCoords[ 0 ] instanceof AreaCoord ) {
+                return CoordsType.AREA;
+            }
             else if ( npos == 1 ) {
                 return CoordsType.SINGLE_POS;
             }
