@@ -1,13 +1,13 @@
 package uk.ac.starlink.topcat.plot2;
 
 import java.awt.Component;
+import javax.swing.ListModel;
 import uk.ac.starlink.table.ColumnData;
 import uk.ac.starlink.table.ColumnInfo;
 import uk.ac.starlink.table.DomainMapper;
-import uk.ac.starlink.table.TimeMapper;
+import uk.ac.starlink.table.TimeDomain;
 import uk.ac.starlink.topcat.ColumnDataComboBoxModel;
 import uk.ac.starlink.topcat.TopcatModel;
-import uk.ac.starlink.topcat.TypedListModel;
 import uk.ac.starlink.ttools.plot2.DataGeom;
 import uk.ac.starlink.ttools.plot2.GangerFactory;
 import uk.ac.starlink.ttools.plot2.PlotType;
@@ -35,37 +35,12 @@ public class TimePlotWindow
      * @param  tablesModel  list of available tables
      */
     public TimePlotWindow( Component parent,
-                           TypedListModel<TopcatModel> tablesModel ) {
+                           ListModel<TopcatModel> tablesModel ) {
         super( "Time Plot", parent, PLOT_TYPE, PLOT_GUI, tablesModel );
         getToolBar().addSeparator();
         addHelp( "TimePlotWindow" );
     }
 
-    /**
-     * Returns the index of the column within a given colum model at which
-     * a value in the time domain can be found.
-     *
-     * @param  colModel   list of columns from a table
-     * @return    index in list of the first/best time (epoch) column,
-     *            or -1 if nothing suitable can be found
-     */
-    private static int getTimeIndex( ColumnDataComboBoxModel colModel ) {
-        if ( colModel != null ) {
-            for ( int ic = 0; ic < colModel.getSize(); ic++ ) {
-                ColumnData cdata = colModel.getColumnDataAt( ic );
-                if ( cdata != null ) {
-                    ColumnInfo info = cdata.getColumnInfo();
-                    for ( DomainMapper mapper : info.getDomainMappers() ) {
-                        if ( mapper instanceof TimeMapper ) {
-                            return ic;
-                        }
-                    }
-                }
-            }
-        }
-        return -1;
-    }
-
     /**
      * Defines GUI features specific to time plot.
      */
@@ -76,6 +51,7 @@ public class TimePlotWindow
             return new TimeAxisController();
         }
         public PositionCoordPanel createPositionCoordPanel( final int npos ) {
+            final TimeDomain domain = TimeDomain.INSTANCE;
             DataGeom geom = PLOT_TYPE.getPointDataGeoms()[ 0 ];
             Coord[] coords =
                 PositionCoordPanel.multiplyCoords( geom.getPosCoords(), npos );
@@ -91,31 +67,49 @@ public class TimePlotWindow
                         getColumnSelector( 0, 0 );
                     ColumnDataComboBoxModel yModel =
                         getColumnSelector( 1, 0 );
-                    int ict = getTimeIndex( timeModel );
-                    if ( timeModel != null && yModel != null && ict >= 0 ) {
-                        timeModel.setSelectedItem( timeModel
-                                                  .getElementAt( ict ) );
-                        int icy = -1;
-                        for ( int ic = 0; ic < yModel.getSize() && icy < 0;
-                              ic++ ) {
-                            ColumnData cdata = yModel.getColumnDataAt( ic );
-                            if ( ic != ict && cdata != null ) {
-                                ColumnInfo info = cdata.getColumnInfo();
-                                if ( Number.class
-                                    .isAssignableFrom( info
-                                                      .getContentClass() ) ) {
-                                    icy = ic;
+                    ColumnData timeData = null;
+                    for ( int ic = 0;
+                          timeData == null && ic < timeModel.getSize(); ic++ ) {
+                        ColumnData cdata = timeModel.getColumnDataAt( ic );
+                        if ( cdata != null ) {
+                            ColumnInfo info = cdata.getColumnInfo();
+                            if ( info != null ) {
+                                if ( domain.getProbableMapper( info )
+                                     != null ) {
+                                    timeData = cdata;
                                 }
                             }
                         }
-                        if ( icy >= 0 ) {
-                            yModel.setSelectedItem( yModel
-                                                   .getElementAt( icy ) );
+                    }
+
+                    /* If successful, fill in a Y value as well. */
+                    if ( timeData != null ) {
+                        timeModel.setSelectedItem( timeData );
+                        ColumnData yData = null;
+                        for ( int ic = 0;
+                              yData == null && ic < yModel.getSize(); ic++ ) {
+                            ColumnData cdata = yModel.getColumnDataAt( ic );
+                            if ( cdata != null ) {
+                                ColumnInfo info = cdata.getColumnInfo();
+                                if ( info != null &&
+                                     domain.getProbableMapper( info ) == null &&
+                                     Number.class
+                                    .isAssignableFrom( info
+                                                      .getContentClass() ) ) {
+                                    yData = cdata;
+                                }
+                            }
+                        }
+                        if ( yData != null ) {
+                            yModel.setSelectedItem( yData );
                         }
                     }
                 }
             };
         }
+        public PositionCoordPanel createAreaCoordPanel() {
+            throw new UnsupportedOperationException();
+        }
         public boolean hasPositions() {
             return true;
         }
