@@ -7,6 +7,7 @@ import gnu.jel.Library;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 import uk.ac.starlink.table.ArrayColumn;
+import uk.ac.starlink.table.ColumnData;
 import uk.ac.starlink.table.ColumnStarTable;
 import uk.ac.starlink.ttools.jel.RandomJELRowReader;
 import uk.ac.starlink.util.TestCase;
@@ -23,12 +24,19 @@ public class JELTest extends TestCase {
     }
 
     public void testLibrary() throws Throwable {
+        testRandomLibrary( false );
+        testRandomLibrary( true );
+    }
+
+    private void testRandomLibrary( boolean isThreadsafe ) throws Throwable {
         ColumnStarTable st = ColumnStarTable.makeTableWithRows( 4 );
         st.addColumn( ArrayColumn
                      .makeColumn( "X", new int[] { 0, 1, 2, 3, } ) );
         st.addColumn( ArrayColumn
                      .makeColumn( "Y", new double[] { 0., 1., 4., 9. } ) );
-        RandomJELRowReader jrr = new RandomJELRowReader( st );
+        RandomJELRowReader jrr =
+            isThreadsafe ? RandomJELRowReader.createConcurrentReader( st )
+                         : RandomJELRowReader.createAccessReader( st );
         for ( int i = 0; i < 2; i++ ) {
             Library lib = TopcatJELUtils.getLibrary( jrr, i > 0 );
             CompiledExpression compex =
@@ -38,13 +46,9 @@ public class JELTest extends TestCase {
                 assertEquals( result, 
                               ( (Double) jrr.evaluateAtRow( compex, j ) )
                              .doubleValue() );
-                jrr.setCurrentRow( j );
-                assertEquals( result,
-                              ( (Double) jrr.evaluate( compex ) )
-                             .doubleValue() );
             }
             try {
-                Evaluator.compile( "tits", lib, null );
+                Evaluator.compile( "toots", lib, null );
                 fail();
             }
             catch ( CompilationException e ) {
